==> zio-aws-kendra_2.13-5.17.151.1-sources.jar: zio/aws/kendra/model/DisassociatePersonasFromEntitiesResponse.scala <==
package zio.aws.kendra.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DisassociatePersonasFromEntitiesResponse(
    failedEntityList: Option[Iterable[zio.aws.kendra.model.FailedEntity]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse = {
    import DisassociatePersonasFromEntitiesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
      .builder()
      .optionallyWith(
        failedEntityList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedEntityList)
      .build()
  }
  def asReadOnly
      : zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse.ReadOnly =
    zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse
      .wrap(buildAwsValue())
}
object DisassociatePersonasFromEntitiesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse =
      zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse(
        failedEntityList.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def failedEntityList
        : Option[List[zio.aws.kendra.model.FailedEntity.ReadOnly]]
    def getFailedEntityList
        : ZIO[Any, AwsError, List[zio.aws.kendra.model.FailedEntity.ReadOnly]] =
      AwsError.unwrapOptionField("failedEntityList", failedEntityList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
  ) extends zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse.ReadOnly {
    override val failedEntityList
        : Option[List[zio.aws.kendra.model.FailedEntity.ReadOnly]] = scala
      .Option(impl.failedEntityList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kendra.model.FailedEntity.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
  ): zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kendra_2.13-5.19.33.2-sources.jar: zio/aws/kendra/model/DisassociatePersonasFromEntitiesResponse.scala <==
package zio.aws.kendra.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisassociatePersonasFromEntitiesResponse(
    failedEntityList: Optional[Iterable[zio.aws.kendra.model.FailedEntity]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse = {
    import DisassociatePersonasFromEntitiesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
      .builder()
      .optionallyWith(
        failedEntityList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedEntityList)
      .build()
  }
  def asReadOnly
      : zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse.ReadOnly =
    zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse
      .wrap(buildAwsValue())
}
object DisassociatePersonasFromEntitiesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse =
      zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse(
        failedEntityList.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def failedEntityList
        : Optional[List[zio.aws.kendra.model.FailedEntity.ReadOnly]]
    def getFailedEntityList
        : ZIO[Any, AwsError, List[zio.aws.kendra.model.FailedEntity.ReadOnly]] =
      AwsError.unwrapOptionField("failedEntityList", failedEntityList)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
  ) extends zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse.ReadOnly {
    override val failedEntityList
        : Optional[List[zio.aws.kendra.model.FailedEntity.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.failedEntityList())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.kendra.model.FailedEntity.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kendra.model.DisassociatePersonasFromEntitiesResponse
  ): zio.aws.kendra.model.DisassociatePersonasFromEntitiesResponse.ReadOnly =
    new Wrapper(impl)
}
